# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr

class ContactAddress(BaseModel):
    """
    ContactAddress
    """
    city: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    street_and_number: Optional[StrictStr] = None
    company: Optional[StrictStr] = None
    postal_code: Optional[StrictStr] = None
    __properties = ["city", "country", "street_and_number", "company", "postal_code"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ContactAddress:
        """Create an instance of ContactAddress from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ContactAddress:
        """Create an instance of ContactAddress from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ContactAddress.parse_obj(obj)

        _obj = ContactAddress.parse_obj({
            "city": obj.get("city"),
            "country": obj.get("country"),
            "street_and_number": obj.get("street_and_number"),
            "company": obj.get("company"),
            "postal_code": obj.get("postal_code")
        })
        return _obj


